aboutsummaryrefslogtreecommitdiffstats
path: root/examples/charts
diff options
context:
space:
mode:
Diffstat (limited to 'examples/charts')
-rw-r--r--examples/charts/audio.py10
-rw-r--r--examples/charts/callout.py10
-rw-r--r--examples/charts/chartthemes/README.md2
-rw-r--r--examples/charts/chartthemes/main.py10
-rw-r--r--examples/charts/chartthemes/ui_themewidget.py6
-rw-r--r--examples/charts/donutbreakdown.py10
-rw-r--r--examples/charts/legend.py10
-rw-r--r--examples/charts/lineandbar.py10
-rw-r--r--examples/charts/linechart.py10
-rw-r--r--examples/charts/logvalueaxis.py10
-rw-r--r--examples/charts/memoryusage.py8
-rw-r--r--examples/charts/modeldata.py10
-rw-r--r--examples/charts/nesteddonuts.py10
-rw-r--r--examples/charts/percentbarchart.py10
-rw-r--r--examples/charts/piechart.py10
-rw-r--r--examples/charts/qmlpolarchart/qmlpolarchart.py8
-rw-r--r--examples/charts/temperaturerecords.py10
17 files changed, 77 insertions, 77 deletions
diff --git a/examples/charts/chartthemes/README.md b/examples/charts/chartthemes/README.md
index e11fa93c5..806e391d2 100644
--- a/examples/charts/chartthemes/README.md
+++ b/examples/charts/chartthemes/README.md
@@ -3,7 +3,7 @@
To generated the file `ui_themewidget.py`, the following
command need to be executed:
-`pyside2-uic themewidget.ui > ui_themewidget.py`
+`pyside6-uic themewidget.ui > ui_themewidget.py`
Also, if you modify the UI file, then you would need
to run the previous command again.
diff --git a/examples/charts/chartthemes/ui_themewidget.py b/examples/charts/chartthemes/ui_themewidget.py
index bf6703963..d2fdf55bc 100644
--- a/examples/charts/chartthemes/ui_themewidget.py
+++ b/examples/charts/chartthemes/ui_themewidget.py
@@ -8,10 +8,10 @@
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################
-from PySide2.QtCore import (QCoreApplication, QMetaObject, QObject, QPoint,
+from PySide6.QtCore import (QCoreApplication, QMetaObject, QObject, QPoint,
QRect, QSize, QUrl, Qt)
-from PySide2.QtGui import (QColor, QFont, QIcon, QPixmap)
-from PySide2.QtWidgets import *
+from PySide6.QtGui import (QColor, QFont, QIcon, QPixmap)
+from PySide6.QtWidgets import *
class Ui_ThemeWidgetForm(object):
def setupUi(self, ThemeWidgetForm):
diff --git a/examples/charts/audio.py b/examples/charts/audio.py
index f899ac4c8..6d7b4895a 100644
--- a/examples/charts/audio.py
+++ b/examples/charts/audio.py
@@ -39,14 +39,14 @@
##
#############################################################################
"""PySide2 port of the charts/audio example from Qt v5.x"""
import sys
-from PySide2.QtCharts import QtCharts
-from PySide2.QtCore import QPointF
-from PySide2.QtMultimedia import (QAudioDeviceInfo, QAudioFormat,
+from PySide6.QtCharts import QtCharts
+from PySide6.QtCore import QPointF
+from PySide6.QtMultimedia import (QAudioDeviceInfo, QAudioFormat,
QAudioInput)
-from PySide2.QtWidgets import QApplication, QMainWindow, QMessageBox
+from PySide6.QtWidgets import QApplication, QMainWindow, QMessageBox
sampleCount = 2000
resolution = 4
@@ -39,14 +39,14 @@
##
#############################################################################
-"""PySide2 port of the charts/audio example from Qt v5.x"""
+"""PySide6 port of the charts/audio example from Qt v5.x"""
import sys
diff --git a/examples/charts/callout.py b/examples/charts/callout.py
index 54e8eaf24..666b2aae5 100644
--- a/examples/charts/callout.py
+++ b/examples/charts/callout.py
@@ -39,14 +39,14 @@
##
#############################################################################
"""PySide2 port of the Callout example from Qt v5.x"""
import sys
-from PySide2.QtWidgets import (QApplication, QGraphicsScene,
+from PySide6.QtWidgets import (QApplication, QGraphicsScene,
QGraphicsView, QGraphicsSimpleTextItem, QGraphicsItem)
-from PySide2.QtCore import Qt, QPointF, QRectF, QRect
-from PySide2.QtCharts import QtCharts
-from PySide2.QtGui import QPainter, QFont, QFontMetrics, QPainterPath, QColor
+from PySide6.QtCore import Qt, QPointF, QRectF, QRect
+from PySide6.QtCharts import QtCharts
+from PySide6.QtGui import QPainter, QFont, QFontMetrics, QPainterPath, QColor
class Callout(QGraphicsItem):
@@ -39,14 +39,14 @@
##
#############################################################################
-"""PySide2 port of the Callout example from Qt v5.x"""
+"""PySide6 port of the Callout example from Qt v5.x"""
import sys
diff --git a/examples/charts/chartthemes/main.py b/examples/charts/chartthemes/main.py
index e18e92cf2..423806490 100644
--- a/examples/charts/chartthemes/main.py
+++ b/examples/charts/chartthemes/main.py
@@ -38,14 +38,14 @@
##
#############################################################################
"""PySide2 port of the Chart Themes example from Qt v5.x"""
import sys
-from PySide2.QtCore import QPointF, Qt
-from PySide2.QtGui import QColor, QPainter, QPalette
-from PySide2.QtWidgets import (QApplication, QMainWindow, QSizePolicy,
+from PySide6.QtCore import QPointF, Qt
+from PySide6.QtGui import QColor, QPainter, QPalette
+from PySide6.QtWidgets import (QApplication, QMainWindow, QSizePolicy,
QWidget)
-from PySide2.QtCharts import QtCharts
+from PySide6.QtCharts import QtCharts
from ui_themewidget import Ui_ThemeWidgetForm as ui
@@ -38,14 +38,14 @@
##
#############################################################################
-"""PySide2 port of the Chart Themes example from Qt v5.x"""
+"""PySide6 port of the Chart Themes example from Qt v5.x"""
import sys
diff --git a/examples/charts/donutbreakdown.py b/examples/charts/donutbreakdown.py
index 712bea577..cde318087 100644
--- a/examples/charts/donutbreakdown.py
+++ b/examples/charts/donutbreakdown.py
@@ -38,14 +38,14 @@
##
#############################################################################
"""PySide2 port of the Donut Chart Breakdown example from Qt v5.x"""
import sys
-from PySide2.QtCore import Qt
-from PySide2.QtGui import QColor, QFont, QPainter
-from PySide2.QtWidgets import QApplication, QMainWindow
-from PySide2.QtCharts import QtCharts
+from PySide6.QtCore import Qt
+from PySide6.QtGui import QColor, QFont, QPainter
+from PySide6.QtWidgets import QApplication, QMainWindow
+from PySide6.QtCharts import QtCharts
class MainSlice(QtCharts.QPieSlice):
def __init__(self, breakdown_series, parent=None):
@@ -38,14 +38,14 @@
##
#############################################################################
-"""PySide2 port of the Donut Chart Breakdown example from Qt v5.x"""
+"""PySide6 port of the Donut Chart Breakdown example from Qt v5.x"""
import sys
diff --git a/examples/charts/legend.py b/examples/charts/legend.py
index 47099e729..b833ccedd 100644
--- a/examples/charts/legend.py
+++ b/examples/charts/legend.py
@@ -38,14 +38,14 @@
##
#############################################################################
"""PySide2 port of the Legend example from Qt v5.x"""
import sys
-from PySide2.QtCore import Qt, QRectF
-from PySide2.QtGui import QBrush, QColor, QPainter, QPen
-from PySide2.QtWidgets import (QApplication, QDoubleSpinBox,
+from PySide6.QtCore import Qt, QRectF
+from PySide6.QtGui import QBrush, QColor, QPainter, QPen
+from PySide6.QtWidgets import (QApplication, QDoubleSpinBox,
QFormLayout, QGridLayout, QGroupBox, QPushButton, QWidget)
-from PySide2.QtCharts import QtCharts
+from PySide6.QtCharts import QtCharts
class MainWidget(QWidget):
def __init__(self, parent=None):
@@ -38,14 +38,14 @@
##
#############################################################################
-"""PySide2 port of the Legend example from Qt v5.x"""
+"""PySide6 port of the Legend example from Qt v5.x"""
import sys
diff --git a/examples/charts/lineandbar.py b/examples/charts/lineandbar.py
index 0a29aa786..e06298e63 100644
--- a/examples/charts/lineandbar.py
+++ b/examples/charts/lineandbar.py
@@ -39,13 +39,13 @@
##
#############################################################################
"""PySide2 port of the line/bar example from Qt v5.x"""
import sys
-from PySide2.QtCore import QPoint, Qt
-from PySide2.QtGui import QPainter
-from PySide2.QtWidgets import QMainWindow, QApplication
-from PySide2.QtCharts import QtCharts
+from PySide6.QtCore import QPoint, Qt
+from PySide6.QtGui import QPainter
+from PySide6.QtWidgets import QMainWindow, QApplication
+from PySide6.QtCharts import QtCharts
class TestChart(QMainWindow):
@@ -39,13 +39,13 @@
##
#############################################################################
-"""PySide2 port of the line/bar example from Qt v5.x"""
+"""PySide6 port of the line/bar example from Qt v5.x"""
import sys
diff --git a/examples/charts/linechart.py b/examples/charts/linechart.py
index 98d17b35c..7a3e15f60 100644
--- a/examples/charts/linechart.py
+++ b/examples/charts/linechart.py
@@ -38,13 +38,13 @@
##
#############################################################################
"""PySide2 port of the linechart example from Qt v5.x"""
import sys
-from PySide2.QtCore import QPointF
-from PySide2.QtGui import QPainter
-from PySide2.QtWidgets import QMainWindow, QApplication
-from PySide2.QtCharts import QtCharts
+from PySide6.QtCore import QPointF
+from PySide6.QtGui import QPainter
+from PySide6.QtWidgets import QMainWindow, QApplication
+from PySide6.QtCharts import QtCharts
class TestChart(QMainWindow):
@@ -38,13 +38,13 @@
##
#############################################################################
-"""PySide2 port of the linechart example from Qt v5.x"""
+"""PySide6 port of the linechart example from Qt v5.x"""
import sys
diff --git a/examples/charts/logvalueaxis.py b/examples/charts/logvalueaxis.py
index 7fb5604cd..37558ecb7 100644
--- a/examples/charts/logvalueaxis.py
+++ b/examples/charts/logvalueaxis.py
@@ -38,15 +38,15 @@
##
#############################################################################
"""PySide2 port of the Logarithmic Axis Example from Qt v5.x"""
import sys
-from PySide2.QtCore import Qt, QPointF
-from PySide2.QtGui import QPainter
-from PySide2.QtWidgets import QMainWindow, QApplication
-from PySide2.QtCharts import QtCharts
+from PySide6.QtCore import Qt, QPointF
+from PySide6.QtGui import QPainter
+from PySide6.QtWidgets import QMainWindow, QApplication
+from PySide6.QtCharts import QtCharts
class TestChart(QMainWindow):
@@ -38,15 +38,15 @@
##
#############################################################################
-"""PySide2 port of the Logarithmic Axis Example from Qt v5.x"""
+"""PySide6 port of the Logarithmic Axis Example from Qt v5.x"""
import sys
diff --git a/examples/charts/memoryusage.py b/examples/charts/memoryusage.py
index 4954b9cd7..9d7a99311 100644
--- a/examples/charts/memoryusage.py
+++ b/examples/charts/memoryusage.py
@@ -39,13 +39,13 @@
##
#############################################################################
"""PySide2 Charts example: Simple memory usage viewer"""
import os
import sys
-from PySide2.QtCore import QProcess
-from PySide2.QtWidgets import QApplication, QMainWindow
-from PySide2.QtCharts import QtCharts
+from PySide6.QtCore import QProcess
+from PySide6.QtWidgets import QApplication, QMainWindow
+from PySide6.QtCharts import QtCharts
def runProcess(command, arguments):
process = QProcess()
@@ -39,13 +39,13 @@
##
#############################################################################
-"""PySide2 Charts example: Simple memory usage viewer"""
+"""PySide6 Charts example: Simple memory usage viewer"""
import os
import sys
diff --git a/examples/charts/modeldata.py b/examples/charts/modeldata.py
index aa53e74ba..739b73d63 100644
--- a/examples/charts/modeldata.py
+++ b/examples/charts/modeldata.py
@@ -39,16 +39,16 @@
##
#############################################################################
"""PySide2 port of the Model Data example from Qt v5.x"""
import sys
from random import randrange
-from PySide2.QtCore import QAbstractTableModel, QModelIndex, QRect, Qt
-from PySide2.QtGui import QColor, QPainter
-from PySide2.QtWidgets import (QApplication, QGridLayout, QHeaderView,
+from PySide6.QtCore import QAbstractTableModel, QModelIndex, QRect, Qt
+from PySide6.QtGui import QColor, QPainter
+from PySide6.QtWidgets import (QApplication, QGridLayout, QHeaderView,
QTableView, QWidget)
-from PySide2.QtCharts import QtCharts
+from PySide6.QtCharts import QtCharts
class CustomTableModel(QAbstractTableModel):
def __init__(self):
@@ -39,16 +39,16 @@
##
#############################################################################
-"""PySide2 port of the Model Data example from Qt v5.x"""
+"""PySide6 port of the Model Data example from Qt v5.x"""
import sys
from random import randrange
diff --git a/examples/charts/nesteddonuts.py b/examples/charts/nesteddonuts.py
index 77bbabfc7..09c77d022 100644
--- a/examples/charts/nesteddonuts.py
+++ b/examples/charts/nesteddonuts.py
@@ -39,14 +39,14 @@
##
#############################################################################
"""PySide2 port of the Nested Donuts example from Qt v5.x"""
import sys
-from PySide2.QtCore import Qt, QTimer
-from PySide2.QtGui import QPainter
-from PySide2.QtWidgets import QApplication, QGridLayout, QWidget
-from PySide2.QtCharts import QtCharts
+from PySide6.QtCore import Qt, QTimer
+from PySide6.QtGui import QPainter
+from PySide6.QtWidgets import QApplication, QGridLayout, QWidget
+from PySide6.QtCharts import QtCharts
from random import randrange
from functools import partial
@@ -39,14 +39,14 @@
##
#############################################################################
-"""PySide2 port of the Nested Donuts example from Qt v5.x"""
+"""PySide6 port of the Nested Donuts example from Qt v5.x"""
import sys
diff --git a/examples/charts/percentbarchart.py b/examples/charts/percentbarchart.py
index 256070e7f..a70cae7cf 100644
--- a/examples/charts/percentbarchart.py
+++ b/examples/charts/percentbarchart.py
@@ -39,13 +39,13 @@
##
#############################################################################
"""PySide2 port of the Percent Bar Chart example from Qt v5.x"""
import sys
-from PySide2.QtCore import Qt
-from PySide2.QtGui import QPainter
-from PySide2.QtWidgets import (QMainWindow, QApplication)
-from PySide2.QtCharts import QtCharts
+from PySide6.QtCore import Qt
+from PySide6.QtGui import QPainter
+from PySide6.QtWidgets import (QMainWindow, QApplication)
+from PySide6.QtCharts import QtCharts
class MainWindow(QMainWindow):
def __init__(self):
@@ -39,13 +39,13 @@
##
#############################################################################
-"""PySide2 port of the Percent Bar Chart example from Qt v5.x"""
+"""PySide6 port of the Percent Bar Chart example from Qt v5.x"""
import sys
diff --git a/examples/charts/piechart.py b/examples/charts/piechart.py
index 820da8b91..e1131d96e 100644
--- a/examples/charts/piechart.py
+++ b/examples/charts/piechart.py
@@ -38,13 +38,13 @@
##
#############################################################################
"""PySide2 port of the Pie Chart Example from Qt v5.x"""
import sys
-from PySide2.QtCore import Qt
-from PySide2.QtGui import QPainter, QPen
-from PySide2.QtWidgets import QMainWindow, QApplication
-from PySide2.QtCharts import QtCharts
+from PySide6.QtCore import Qt
+from PySide6.QtGui import QPainter, QPen
+from PySide6.QtWidgets import QMainWindow, QApplication
+from PySide6.QtCharts import QtCharts
class TestChart(QMainWindow):
@@ -38,13 +38,13 @@
##
#############################################################################
-"""PySide2 port of the Pie Chart Example from Qt v5.x"""
+"""PySide6 port of the Pie Chart Example from Qt v5.x"""
import sys
diff --git a/examples/charts/qmlpolarchart/qmlpolarchart.py b/examples/charts/qmlpolarchart/qmlpolarchart.py
index 4398169b0..006a801f1 100644
--- a/examples/charts/qmlpolarchart/qmlpolarchart.py
+++ b/examples/charts/qmlpolarchart/qmlpolarchart.py
@@ -38,13 +38,13 @@
##
#############################################################################
"""PySide2 port of the QML Polar Chart Example from Qt v5.x"""
import sys
import os
-from PySide2.QtQuick import QQuickView
-from PySide2.QtCore import Qt, QUrl
-from PySide2.QtWidgets import QApplication, QMainWindow
+from PySide6.QtQuick import QQuickView
+from PySide6.QtCore import Qt, QUrl
+from PySide6.QtWidgets import QApplication, QMainWindow
if __name__ == '__main__':
@@ -38,13 +38,13 @@
##
#############################################################################
-"""PySide2 port of the QML Polar Chart Example from Qt v5.x"""
+"""PySide6 port of the QML Polar Chart Example from Qt v5.x"""
import sys
import os
diff --git a/examples/charts/temperaturerecords.py b/examples/charts/temperaturerecords.py
index dfd4dd67c..9c2cad1df 100644
--- a/examples/charts/temperaturerecords.py
+++ b/examples/charts/temperaturerecords.py
@@ -38,13 +38,13 @@
##
#############################################################################
"""PySide2 port of the Temperature Records example from Qt v5.x"""
import sys
-from PySide2.QtCore import Qt
-from PySide2.QtGui import QPainter
-from PySide2.QtWidgets import QMainWindow, QApplication
-from PySide2.QtCharts import QtCharts
+from PySide6.QtCore import Qt
+from PySide6.QtGui import QPainter
+from PySide6.QtWidgets import QMainWindow, QApplication
+from PySide6.QtCharts import QtCharts
class MainWindow(QMainWindow):
@@ -38,13 +38,13 @@
##
#############################################################################
-"""PySide2 port of the Temperature Records example from Qt v5.x"""
+"""PySide6 port of the Temperature Records example from Qt v5.x"""
import sys